# Security Policy

## Supported Versions

| Version   | Supported          |
| --------- | ------------------ |
| >1.5.x    | ✅                 |

## Disclosure

All known security vulnerabilities must be disclosed publically within 30 days of a detection during regular monitoring.

## Reporting a Vulnerability

A security vulnerability must never be posted in Issues.
This must be done directly through GitHub or via help@oziproject.dev
